==> jc-1.4.0.tar.gz: java/lang/reflect/Proxy__24ProxyData.h <==
// final class java.lang.reflect.Proxy$ProxyData

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 72f8e34b95757c00 java_lang_reflect_Proxy__24ProxyData

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxyData_H_
#define _JC_java_lang_reflect_Proxy__24ProxyData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Proxy__24ProxyData$object;
struct _jc_java_lang_reflect_Proxy__24ProxyType$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs	_jc_java_lang_reflect_Proxy__24ProxyData$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$refs	_jc_java_lang_reflect_Proxy__24ProxyData$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$nonrefs	_jc_java_lang_reflect_Proxy__24ProxyData$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$object	_jc_java_lang_reflect_Proxy__24ProxyData$object;

typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct	_jc_java_lang_reflect_Proxy__24ProxyData$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vmethods	_jc_java_lang_reflect_Proxy__24ProxyData$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vtable	_jc_java_lang_reflect_Proxy__24ProxyData$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vtype	_jc_java_lang_reflect_Proxy__24ProxyData$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct {
	jint	count;
};
extern _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct _jc_java_lang_reflect_Proxy__24ProxyData$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxyData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *);

// Virtual methods
extern void _jc_java_lang_reflect_Proxy__24ProxyData$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyData$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_lang_reflect_Proxy__24ProxyData$method$getPackage$74027928ec46bc24(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_reflect_Proxy__24ProxyData$object *_jc_java_lang_reflect_Proxy__24ProxyData$method$getProxyData$80830450ad112263(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *);

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *);
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxyData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxyData$vmethods	java_lang_reflect_Proxy__24ProxyData;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxyData$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxyData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs {
	struct _jc_java_lang_String$object	*pack;
	_jc_object_array	*interfaces;
	_jc_object_array	*methods;
	_jc_object_array	*exceptions;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyData$refs {
    _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs	java_lang_reflect_Proxy__24ProxyData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs	java_lang_reflect_Proxy__24ProxyData;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$object {
	_jc_java_lang_reflect_Proxy__24ProxyData$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxyData$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxyData$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxyData$vtype _jc_java_lang_reflect_Proxy__24ProxyData$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxyData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxyData$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxyData_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/Proxy__24ProxyData.h <==
// final class java.lang.reflect.Proxy$ProxyData

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 72f8e34b95757c00 java_lang_reflect_Proxy__24ProxyData

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxyData_H_
#define _JC_java_lang_reflect_Proxy__24ProxyData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Proxy__24ProxyData$object;
struct _jc_java_lang_reflect_Proxy__24ProxyType$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs	_jc_java_lang_reflect_Proxy__24ProxyData$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$refs	_jc_java_lang_reflect_Proxy__24ProxyData$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$nonrefs	_jc_java_lang_reflect_Proxy__24ProxyData$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$object	_jc_java_lang_reflect_Proxy__24ProxyData$object;

typedef struct _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct	_jc_java_lang_reflect_Proxy__24ProxyData$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vmethods	_jc_java_lang_reflect_Proxy__24ProxyData$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vtable	_jc_java_lang_reflect_Proxy__24ProxyData$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyData$vtype	_jc_java_lang_reflect_Proxy__24ProxyData$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct {
	jint	count;
};
extern _jc_java_lang_reflect_Proxy__24ProxyData$fields_struct _jc_java_lang_reflect_Proxy__24ProxyData$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxyData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_lang_reflect_Proxy__24ProxyData$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyData$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_lang_reflect_Proxy__24ProxyData$method$getPackage$74027928ec46bc24(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_reflect_Proxy__24ProxyData$object *_jc_java_lang_reflect_Proxy__24ProxyData$method$getProxyData$80830450ad112263(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxyData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxyData$vmethods	java_lang_reflect_Proxy__24ProxyData;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxyData$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxyData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs {
	struct _jc_java_lang_String$object	*pack;
	_jc_object_array	*interfaces;
	_jc_object_array	*methods;
	_jc_object_array	*exceptions;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyData$refs {
    _jc_java_lang_reflect_Proxy__24ProxyData$sub_refs	java_lang_reflect_Proxy__24ProxyData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxyData$sub_nonrefs	java_lang_reflect_Proxy__24ProxyData;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxyData$object {
	_jc_java_lang_reflect_Proxy__24ProxyData$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxyData$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxyData$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxyData$vtype _jc_java_lang_reflect_Proxy__24ProxyData$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxyData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxyData$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxyData_H_ */
